package biomesoplenty.items;

import java.util.List;

import net.minecraft.block.Block;
import net.minecraft.client.renderer.texture.IconRegister;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.Icon;
import net.minecraft.util.MathHelper;
import net.minecraft.world.World;
import biomesoplenty.BiomesOPlenty;
import biomesoplenty.api.Blocks;
import biomesoplenty.configuration.configfile.BOPConfigurationIDs;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;

public class ItemBOPAncientStaff extends Item
{
	private static String[] parts = {"ancientstaff", "staffhandle", "staffpole", "stafftopper", "ancientstaffbroken"};
	@SideOnly(Side.CLIENT)
	private Icon[] textures;

	public ItemBOPAncientStaff(int par1)
	{
		super(par1);
		maxStackSize = 1;
		setCreativeTab(BiomesOPlenty.tabBiomesOPlenty);
	}
	
    /**
     * Returns True is the item is renderer in full 3D when hold.
     */
	@Override
    public boolean isFull3D()
    {
		return true;
    }

	@Override
	public boolean hasEffect(ItemStack itemStack, int pass)
	{
		if (itemStack.getItemDamage() == 0)
			return true;
		else
			return false;
	}

	@Override
	public void registerIcons(IconRegister iconRegister)
	{
		textures = new Icon[parts.length];

		for (int i = 0; i < parts.length; ++i) {
			textures[i] = iconRegister.registerIcon("biomesoplenty:"+parts[i]);
		}

		//textures[parts.length - 1] = iconRegister.registerIcon("biomesoplenty:ancientstaff");
	}

	@Override
	public String getUnlocalizedName(ItemStack itemStack)
	{
		int meta = itemStack.getItemDamage();
		if (meta < 0 || meta >= parts.length) {
			meta = 0;
		}

		return super.getUnlocalizedName() + "." + parts[meta];
	}

	@Override
	public Icon getIconFromDamage(int meta)
	{
		if (meta < 0 || meta >= textures.length) {
			meta = 0;
		}

		return textures[meta];
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Override
	public void getSubItems(int itemId, CreativeTabs creativeTab, List subTypes)
	{
		for(int meta = 0; meta < parts.length; ++meta) {
			subTypes.add(new ItemStack(itemId, 1, meta));
		}
	}

	@Override
	public ItemStack onItemRightClick(ItemStack par1ItemStack, World par2World, EntityPlayer par3EntityPlayer)
	{
		if (par3EntityPlayer.dimension == 0 || par3EntityPlayer.dimension == BOPConfigurationIDs.promisedLandDimID)
		{
			int i = MathHelper.floor_double(par3EntityPlayer.posX - 8);
			int j = 145;
			int k = MathHelper.floor_double(par3EntityPlayer.posZ - 8);

			boolean isAir = true;

			for (int iy = -1; iy < 4; iy++)
			{
				for (int ix = -2; ix < 3; ix++) {
					for (int iz = -2; iz < 3; iz++)
						if (!par2World.isAirBlock(i + ix, j + iy, k + iz))
						{
							isAir = false;
						}
				}
			}

			if (par1ItemStack.getItemDamage() == 0)
			{
				if (isAir)
				{

					if (!par3EntityPlayer.worldObj.isRemote)
					{
						if (par3EntityPlayer.dimension == 0)
						{
							par3EntityPlayer.addChatMessage("phrase.bop.promisedPortalOverworld");
						}
						else
						{
							par3EntityPlayer.addChatMessage("phrase.bop.promisedPortalOther");
						}
					}



					boolean flag;

					par2World.setBlock(i + 1, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 1, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 1, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 1, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 3, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 4, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 4, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 5, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 2, j + 9, k + 4, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 5, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 9, Block.grass.blockID);
					par2World.setBlock(i + 2, j + 9, k + 10, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 3, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 9, k + 5, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 9, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 3, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 3, j + 10, k + 4, Block.wood.blockID);
					par2World.setBlock(i + 3, j + 10, k + 5, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 3, j + 10, k + 6, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 3, j + 10, k + 7, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 3, j + 10, k + 8, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 3, j + 10, k + 9, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 3, j + 10, k + 10, Block.wood.blockID);
					par2World.setBlock(i + 3, j + 11, k + 4, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 3, j + 11, k + 10, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 3, j + 12, k + 4, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 3, j + 12, k + 10, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 3, j + 14, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 3, j + 14, k + 5, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 3, j + 14, k + 6, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 3, j + 14, k + 7, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 3, j + 14, k + 8, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 3, j + 14, k + 9, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 3, j + 14, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 4, j + 5, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 6, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 4, j + 9, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 4, Block.grass.blockID);
					par2World.setBlock(i + 4, j + 9, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 10, Block.grass.blockID);
					par2World.setBlock(i + 4, j + 9, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 4, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 4, j + 10, k + 3, Block.wood.blockID);
					par2World.setBlock(i + 4, j + 10, k + 4, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 4, j + 10, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 10, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 10, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 10, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 10, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 10, k + 10, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 4, j + 10, k + 11, Block.wood.blockID);
					par2World.setBlock(i + 4, j + 11, k + 3, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 4, j + 11, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 11, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 11, k + 11, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 4, j + 12, k + 3, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 4, j + 12, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 12, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 12, k + 11, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 4, j + 13, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 13, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 4, j + 14, k + 3, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 4, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 14, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 4, j + 14, k + 11, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 15, k + 5, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 15, k + 6, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 15, k + 7, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 15, k + 8, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 4, j + 15, k + 9, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 2, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 3, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 4, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 4, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 4, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 5, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 8, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 8, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 5, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 5, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 9, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 9, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 9, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 9, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 9, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 5, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 5, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 5, j + 10, k + 3, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 5, j + 10, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 10, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 10, k + 6, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 5, j + 10, k + 7, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 5, j + 10, k + 8, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 5, j + 10, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 10, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 10, k + 11, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 5, j + 11, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 11, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 12, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 12, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 13, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 13, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 14, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 14, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 5, j + 15, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 15, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 15, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 15, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 15, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 15, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 15, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 5, j + 16, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 16, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 16, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 16, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 16, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 17, k + 5, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 17, k + 6, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 17, k + 7, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 17, k + 8, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 5, j + 17, k + 9, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 3, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 4, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 4, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 4, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 5, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 6, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 7, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 7, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 7, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 8, k + 6, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 6, j + 8, k + 7, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 6, j + 8, k + 8, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 6, j + 8, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 8, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 9, k + 1, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 9, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 9, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 6, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 9, k + 13, Block.grass.blockID);
					par2World.setBlock(i + 6, j + 10, k + 3, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 6, j + 10, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 10, k + 5, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 6, j + 10, k + 9, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 10, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 10, k + 11, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 6, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 14, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 14, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 6, j + 15, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 15, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 15, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 15, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 6, j + 16, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 16, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 17, k + 5, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 17, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 17, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 17, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 17, k + 9, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 6, j + 18, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 18, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 18, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 19, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 19, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 19, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 20, k + 6, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 20, k + 7, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 6, j + 20, k + 8, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 1, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 2, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 3, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 3, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 3, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 3, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 4, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 5, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 6, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 7, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 7, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 7, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 8, k + 6, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 7, j + 8, k + 7, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 7, j + 8, k + 8, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 7, j + 8, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 8, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 9, k + 1, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 9, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 9, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 7, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 9, k + 13, Block.grass.blockID);
					par2World.setBlock(i + 7, j + 10, k + 3, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 7, j + 10, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 10, k + 5, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 10, k + 9, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 10, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 10, k + 11, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 7, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 14, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 14, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 15, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 15, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 15, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 15, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 16, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 16, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 17, k + 5, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 17, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 17, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 17, k + 9, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 18, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 18, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 19, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 19, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 20, k + 6, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 20, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 20, k + 8, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 7, j + 21, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 22, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 7, j + 23, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 3, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 3, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 4, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 4, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 4, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 5, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 7, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 7, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 7, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 1, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 8, k + 6, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 8, j + 8, k + 7, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 8, j + 8, k + 8, Blocks.promisedPortal.get().blockID);
					par2World.setBlock(i + 8, j + 8, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 8, k + 13, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 9, k + 1, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 9, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 9, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 8, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 9, k + 13, Block.grass.blockID);
					par2World.setBlock(i + 8, j + 10, k + 3, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 8, j + 10, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 10, k + 5, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 8, j + 10, k + 9, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 10, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 10, k + 11, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 8, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 14, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 14, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 8, j + 15, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 15, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 15, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 15, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 8, j + 16, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 16, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 17, k + 5, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 17, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 17, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 17, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 17, k + 9, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 8, j + 18, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 18, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 18, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 19, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 19, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 19, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 8, j + 20, k + 6, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 8, j + 20, k + 7, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 8, j + 20, k + 8, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 9, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 5, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 6, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 8, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 8, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 9, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 9, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 9, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 9, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 9, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 9, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 9, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 9, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 9, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 9, j + 10, k + 3, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 9, j + 10, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 10, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 10, k + 6, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 10, k + 7, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 10, k + 8, Block.stairsNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 10, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 10, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 10, k + 11, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 9, j + 11, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 11, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 12, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 12, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 13, k + 4, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 13, k + 10, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 14, k + 4, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 14, k + 10, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 9, j + 15, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 15, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 15, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 15, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 15, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 15, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 15, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 9, j + 16, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 16, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 16, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 16, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 16, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 9, j + 17, k + 5, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 17, k + 6, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 9, j + 17, k + 7, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 9, j + 17, k + 8, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 9, j + 17, k + 9, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 10, j + 4, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 5, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 5, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 5, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 6, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 7, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 2, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 8, k + 12, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 2, Block.grass.blockID);
					par2World.setBlock(i + 10, j + 9, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 4, Block.grass.blockID);
					par2World.setBlock(i + 10, j + 9, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 10, Block.grass.blockID);
					par2World.setBlock(i + 10, j + 9, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 10, j + 9, k + 12, Block.grass.blockID);
					par2World.setBlock(i + 10, j + 10, k + 3, Block.wood.blockID);
					par2World.setBlock(i + 10, j + 10, k + 4, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 10, j + 10, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 10, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 10, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 10, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 10, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 10, k + 10, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 10, j + 10, k + 11, Block.wood.blockID);
					par2World.setBlock(i + 10, j + 11, k + 3, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 10, j + 11, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 11, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 11, k + 11, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 10, j + 12, k + 3, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 10, j + 12, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 12, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 12, k + 11, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 10, j + 13, k + 5, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 13, k + 9, Block.blockNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 14, k + 3, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 14, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 14, k + 5, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 14, k + 6, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 14, k + 7, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 14, k + 8, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 14, k + 9, Block.blockNetherQuartz.blockID);
					par2World.setBlock(i + 10, j + 14, k + 10, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 14, k + 11, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 15, k + 5, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 15, k + 6, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 15, k + 7, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 15, k + 8, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 10, j + 15, k + 9, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 3, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 4, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 4, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 5, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 6, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 7, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 3, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 8, k + 11, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 9, k + 3, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 9, k + 5, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 9, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 9, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 11, j + 9, k + 11, Block.grass.blockID);
					par2World.setBlock(i + 11, j + 10, k + 4, Block.wood.blockID);
					par2World.setBlock(i + 11, j + 10, k + 5, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 11, j + 10, k + 6, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 11, j + 10, k + 7, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 11, j + 10, k + 8, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 11, j + 10, k + 9, Block.stoneSingleSlab.blockID, 7, 2);
					par2World.setBlock(i + 11, j + 10, k + 10, Block.wood.blockID);
					par2World.setBlock(i + 11, j + 11, k + 4, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 11, j + 11, k + 10, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 11, j + 12, k + 4, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 11, j + 12, k + 10, Block.leaves.blockID, 4, 2);
					par2World.setBlock(i + 11, j + 14, k + 4, Block.stairsNetherQuartz.blockID, 2, 2);
					par2World.setBlock(i + 11, j + 14, k + 5, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 14, k + 6, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 14, k + 7, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 14, k + 8, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 14, k + 9, Block.stairsNetherQuartz.blockID, 1, 2);
					par2World.setBlock(i + 11, j + 14, k + 10, Block.stairsNetherQuartz.blockID, 3, 2);
					par2World.setBlock(i + 12, j + 2, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 3, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 4, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 5, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 6, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 6, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 7, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 4, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 5, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 9, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 8, k + 10, Block.dirt.blockID);
					par2World.setBlock(i + 12, j + 9, k + 4, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 5, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 9, Block.grass.blockID);
					par2World.setBlock(i + 12, j + 9, k + 10, Block.grass.blockID);
					par2World.setBlock(i + 13, j + 5, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 6, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 7, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 7, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 7, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 8, k + 6, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 8, k + 7, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 8, k + 8, Block.dirt.blockID);
					par2World.setBlock(i + 13, j + 9, k + 6, Block.grass.blockID);
					par2World.setBlock(i + 13, j + 9, k + 7, Block.grass.blockID);
					par2World.setBlock(i + 13, j + 9, k + 8, Block.grass.blockID);
					par2World.setBlock(i + 0, j + 0, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 1, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 2, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 3, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 3, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 4, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 4, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 5, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 5, k + 7, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 5, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 6, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 6, k + 7, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 6, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 7, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 7, k + 7, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 7, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 8, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 8, k + 7, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 8, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 9, k + 6, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 9, k + 7, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 0, j + 9, k + 8, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 1, j + 10, k + 6, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 1, j + 10, k + 7, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 1, j + 10, k + 8, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 2, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 2, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 3, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 3, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 4, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 4, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 5, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 5, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 6, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 6, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 7, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 7, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 8, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 8, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 9, k + 3, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 9, k + 11, Blocks.ivy.get().blockID, 8, 2);
					par2World.setBlock(i + 2, j + 10, k + 4, Block.plantRed.blockID);
					par2World.setBlock(i + 2, j + 10, k + 5, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 10, k + 6, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 10, k + 7, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 10, k + 8, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 10, k + 9, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 2, j + 10, k + 10, Block.plantRed.blockID);
					par2World.setBlock(i + 3, j + 5, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 3, j + 5, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 3, j + 6, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 3, j + 6, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 3, j + 7, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 3, j + 7, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 3, j + 8, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 3, j + 8, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 3, j + 9, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 3, j + 9, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 3, j + 10, k + 3, Block.plantYellow.blockID);
					par2World.setBlock(i + 3, j + 10, k + 11, Block.plantYellow.blockID);
					par2World.setBlock(i + 4, j + 10, k + 2, Block.plantRed.blockID);
					par2World.setBlock(i + 4, j + 10, k + 12, Block.plantRed.blockID);
					par2World.setBlock(i + 5, j + 10, k + 2, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 5, j + 10, k + 12, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 0, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 1, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 2, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 3, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 3, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 4, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 4, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 5, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 5, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 6, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 6, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 7, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 7, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 8, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 8, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 9, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 6, j + 9, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 6, j + 10, k + 1, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 10, k + 2, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 10, k + 12, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 6, j + 10, k + 13, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 1, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 1, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 2, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 2, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 3, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 3, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 4, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 4, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 5, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 5, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 6, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 6, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 7, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 7, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 8, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 8, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 9, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 7, j + 9, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 7, j + 10, k + 1, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 10, k + 2, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 10, k + 12, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 7, j + 10, k + 13, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 3, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 4, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 4, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 5, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 5, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 6, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 6, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 7, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 7, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 8, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 8, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 9, k + 0, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 8, j + 9, k + 14, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 8, j + 10, k + 1, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 10, k + 2, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 10, k + 12, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 8, j + 10, k + 13, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 10, k + 2, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 9, j + 10, k + 12, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 10, j + 10, k + 2, Block.plantRed.blockID);
					par2World.setBlock(i + 10, j + 10, k + 12, Block.plantRed.blockID);
					par2World.setBlock(i + 11, j + 5, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 11, j + 5, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 11, j + 6, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 11, j + 6, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 11, j + 7, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 11, j + 7, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 11, j + 8, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 11, j + 8, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 11, j + 9, k + 2, Blocks.ivy.get().blockID, 1, 2);
					par2World.setBlock(i + 11, j + 9, k + 12, Blocks.ivy.get().blockID, 4, 2);
					par2World.setBlock(i + 11, j + 10, k + 3, Block.plantYellow.blockID);
					par2World.setBlock(i + 11, j + 10, k + 11, Block.plantYellow.blockID);
					par2World.setBlock(i + 12, j + 2, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 2, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 3, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 3, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 4, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 4, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 5, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 5, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 6, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 6, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 7, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 7, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 8, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 8, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 9, k + 3, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 9, k + 11, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 4, Block.plantRed.blockID);
					par2World.setBlock(i + 12, j + 10, k + 5, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 6, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 7, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 8, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 9, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 12, j + 10, k + 10, Block.plantRed.blockID);
					par2World.setBlock(i + 13, j + 10, k + 6, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 13, j + 10, k + 7, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 13, j + 10, k + 8, Block.tallGrass.blockID, 2, 2);
					par2World.setBlock(i + 14, j + 0, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 1, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 2, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 2, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 3, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 3, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 4, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 4, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 4, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 5, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 5, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 5, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 6, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 6, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 6, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 7, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 7, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 7, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 8, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 8, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 8, k + 8, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 9, k + 6, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 9, k + 7, Blocks.ivy.get().blockID, 2, 2);
					par2World.setBlock(i + 14, j + 9, k + 8, Blocks.ivy.get().blockID, 2, 2);

					par1ItemStack.setItemDamage(4);
				}
			}
		}

		return par1ItemStack;
	}
}
